# Function 6 Round a zone’s position (at CVT index) and vertical width (at CVT index + 1). Arguments on stack: _cvt_zone_

Assembly |  | Stack
--- | --- | ---
PUSHW[ ] | 1 value pushed
6 | function index
FDEF[ ] | FunctionDefinition
DUP[ ] | DuplicateTopStack | cvt_zone cvt_zone
DUP[ ] | DuplicateTopStack | cvt_zone cvt_zone cvt_zone
RCVT[ ] | ReadCVT | cvt_zone cvt_zone zone_position
ROUND[01] | Round | cvt_zone cvt_zone round(zone_position)
WCVTP[ ] | WriteCVTInPixels | cvt_zone
PUSHB[ ] | 1 value pushed
1 | next CVT index | cvt_zone 1
ADD[ ] | Add | cvt_zone+1
DUP[ ] | DuplicateTopStack | cvt_zone+1 cvt_zone+1
DUP[ ] | DuplicateTopStack | cvt_zone+1 cvt_zone+1 cvt_zone+1
RCVT[ ] | ReadCVT | cvt_zone+1 cvt_zone+1 zone_width
RDTG[ ] | RoundDownToGrid
ROUND[01] | Round | cvt_zone+1 cvt_zone+1 round(zone_width)
RTG[ ] | RoundToGrid
WCVTP[ ] | WriteCVTInPixels | cvt_zone+1
PUSHB[ ] | 1 value pushed
1 | next CVT index | cvt_zone+1 1
ADD[ ] | Add | cvt_zone+2
ENDF[ ] | EndFunctionDefinition

Returns on stack: The CVT index of the zone + 2 (next CVT zone index)